@@ -4,6 +4,7 @@
 
 from typing import Any, Callable, Dict, List, Tuple, Union
 from operator import attrgetter
+import math
 import urllib.parse
 
 import numpy as np
@@ -153,7 +154,6 @@ class Element(Base):
     atomic_weight = Column(Float)
     atomic_weight_uncertainty = Column(Float)
     block = Column(String)
-    boiling_point = Column(Float)
     cas = Column(String)
     covalent_radius_bragg = Column(Float)
     covalent_radius_cordero = Column(Float)
@@ -189,7 +189,6 @@ class Element(Base):
     jmol_color = Column(String)
     lattice_constant = Column(Float)
     lattice_structure = Column(String)
-    melting_point = Column(Float)
     mendeleev_number = Column(Integer)
     metallic_radius = Column(Float)
     metallic_radius_c12 = Column(Float)
@@ -201,7 +200,6 @@ class Element(Base):
     pettifor_number = Column(Integer)
     proton_affinity = Column(Float)
     _series_id = Column("series_id", Integer, ForeignKey("series.id"))
-    _series = relationship("Series", uselist=False, lazy="subquery")
     series = association_proxy("_series", "name")
     sources = Column(String)
     specific_heat_capacity = Column(Float)
@@ -218,10 +216,13 @@ class Element(Base):
     vdw_radius_uff = Column(Float)
     vdw_radius_mm3 = Column(Float)
 
-    ionic_radii = relationship("IonicRadius", lazy="subquery")
     _ionization_energies = relationship("IonizationEnergy", lazy="subquery")
     _oxidation_states = relationship("OxidationState", lazy="subquery")
-    isotopes = relationship("Isotope", lazy="subquery")
+    _series = relationship("Series", uselist=False, lazy="subquery")
+
+    ionic_radii = relationship("IonicRadius", lazy="subquery")
+    isotopes = relationship("Isotope", lazy="subquery", back_populates="element")
+    phase_transitions = relationship("PhaseTransition", lazy="subquery")
     screening_constants = relationship("ScreeningConstant", lazy="subquery")
 
     @reconstructor
@@ -264,6 +265,22 @@ class Element(Base):
         """
         return f"InchI=1S/{self.symbol}"
 
+    @property
+    def boiling_point(self) -> Union[float, Dict[str, float]]:
+        """Boiling point"""
+        if len(self.phase_transitions) == 1:
+            return self.phase_transitions[0].boiling_point
+        else:
+            return {pt.allotrope: pt.boiling_point for pt in self.phase_transitions}
+
+    @property
+    def melting_point(self) -> Union[float, Dict[str, float]]:
+        """Melting point"""
+        if len(self.phase_transitions) == 1:
+            return self.phase_transitions[0].melting_point
+        else:
+            return {pt.allotrope: pt.melting_point for pt in self.phase_transitions}
+
     @property
     def nist_webbook_url(self) -> str:
         """URL for the NIST Chemistry WebBook"""
@@ -658,7 +675,6 @@ class Element(Base):
 
     def electronegativity_nagle(self) -> float:
         "Nagle's electronegativity"
-
         if self.dipole_polarizability is not None:
             return nagle(self.nvalence(), self.dipole_polarizability)
 
@@ -681,14 +697,12 @@ class Element(Base):
         """
         Return the number of valence electrons
         """
-
         return self.ec.nvalence(self.block, method=method)
 
     def oxides(self) -> List[str]:
         """
         Return a list of possible oxides based on the oxidation number
         """
-
         oxide_coeffs = [coeffs(ox) for ox in self.oxistates if ox > 0]
         # convert to strings and replace 1 with empty string
         normal_coeffs = [[str(c) if c != 1 else "" for c in t] for t in oxide_coeffs]
@@ -711,18 +725,19 @@ class Element(Base):
             "ionic_radii",
             "isotopes",
             "screening_constants",
+            "phase_transitions",
         ]
         hashable = [(k, v) for k, v in self.__dict__.items() if k not in to_drop]
         return hash(tuple(sorted(hashable)))
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         """Overwrite the defalt comparison"""
         return hash(self) == hash(other)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return "{0} {1} {2}".format(self.atomic_number, self.symbol, self.name)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return "%s(\n%s)" % (
             self.__class__.__name__,
             " ".join(
@@ -828,12 +843,12 @@ class IonicRadius(Base):
     origin = Column(String)
     most_reliable = Column(Boolean)
 
-    def __str__(self):
+    def __str__(self) -> str:
         out = ["{0}={1:>4d}", "{0}={1:5s}", "{0}={1:>6.3f}", "{0}={1:>6.3f}"]
         keys = ["charge", "coordination", "crystal_radius", "ionic_radius"]
         return ", ".join(o.format(k, getattr(self, k)) for o, k in zip(out, keys))
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return "%s(\n%s)" % (
             self.__class__.__name__,
             " ".join(
@@ -866,8 +881,7 @@ class IonizationEnergy(Base):
 
         return "{0:5d} {1:10.5f}".format(self.degree, self.energy)
 
-    def __repr__(self):
-
+    def __repr__(self) -> str:
         return "<IonizationEnergy(atomic_number={a:5d}, degree={d:3d}, energy={e:10.5f})>".format(
             a=self.atomic_number, d=self.degree, e=self.energy
         )
@@ -891,7 +905,7 @@ class OxidationState(Base):
     oxidation_state = Column(Integer)
     category = Column(String)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return ", ".join(
             [
                 f"<OxidationState(id={self.id}",
@@ -918,8 +932,7 @@ class Group(Base):
     symbol = Column(String)
     name = Column(String)
 
-    def __repr__(self):
-
+    def __repr__(self) -> str:
         return "<Group(symbol={s:s}, name={n:s})>".format(s=self.symbol, n=self.name)
 
 
@@ -940,11 +953,28 @@ class Series(Base):
     name = Column(String)
     color = Column(String)
 
-    def __repr__(self):
-
+    def __repr__(self) -> str:
         return "<Series(name={n:s}, color={c:s})>".format(n=self.name, c=self.color)
 
 
+def with_uncertainty(value: float, uncertainty: float, digits: int = 5) -> str:
+    """Format a value with uncertainty using scientific notation.
+
+    Args:
+        value (float): value
+        uncertainty (float): uncertainty of the value
+        digits (int): number of digits after decimal point to print in case
+            uncertainty is `None`
+    """
+    if value is None and uncertainty is None:
+        return "None"
+
+    if uncertainty is None or uncertainty == 0.0:
+        return "{0:.{1}f}".format(value, digits)
+    digits = -int(math.floor(math.log10(uncertainty)))
+    return "{0:.{2}f}({1:.0f})".format(value, uncertainty * 10 ** digits, digits)
+
+
 class Isotope(Base):
     """
     Isotope
@@ -990,26 +1020,69 @@ class Isotope(Base):
     quadrupole_moment_uncertainty = Column(Float)
     spin = Column(String)
 
+    element = relationship("Element", lazy="joined", back_populates="isotopes")
+    decay_modes = relationship("IsotopeDecayMode", lazy="subquery")
+
     @hybrid_property
     def is_stable(self) -> bool:
         """Flag to indicate whether the isotope is stable"""
         return not self.is_radioactive
 
-    def __str__(self):
-
-        mfmt = "" if self.mass is None else "10.5f"
-        afmt = "" if self.abundance is None else "5.3f"
-        return "{0:5d} {1:5d} {2:{mfmt}} {3:{afmt}}".format(
+    def __str__(self) -> str:
+        return "atomic_number={0:5d}, mass_number={1:5d}, mass={2:10s}, abundance={3:10s}".format(
             self.atomic_number,
             self.mass_number,
-            self.mass,
-            self.abundance,
-            mfmt=mfmt,
-            afmt=afmt,
+            with_uncertainty(self.mass, self.mass_uncertainty, digits=5),
+            with_uncertainty(self.abundance, self.abundance_uncertainty, digits=3),
         )
 
-    def __repr__(self):
-        return f"<Isotope(Z={self.atomic_number}, A={self.mass_number}, mass={self.mass}, abundance={self.abundance})>"
+    def __repr__(self) -> str:
+        return ", ".join(
+            [
+                f"<Isotope(Z={self.atomic_number}",
+                f"A={self.mass_number}",
+                f"mass={with_uncertainty(self.mass, self.mass_uncertainty, 5)}",
+                f"abundance={with_uncertainty(self.abundance, self.abundance_uncertainty, 3)})>",
+            ]
+        )
+
+
+class IsotopeDecayMode(Base):
+    """
+    IsotopeDecayMode
+
+    Args:
+        mode (str): ASCII symbol for the decay mode
+        relation (str): one of =, ~, <, > marking the intensity value
+        intensity (float): intensity value
+        is_allowed_not_observed (bool): if `True` it means that the decay mode is
+            energetically allowed, but not experimentally observed
+        is_observed_intensity_unknown (bool): if `True` it means that the decay mode
+            is observed, but its intensity is not experimentally known
+    """
+
+    __tablename__ = "isotopedecaymodes"
+
+    id = Column(Integer, primary_key=True)
+    isotope_id = Column(ForeignKey("isotopes.id"))
+    mode = Column(String(10), nullable=False)
+    relation = Column(String(1))
+    intensity = Column(Float, nullable=True)
+    is_allowed_not_observed = Column(Boolean)
+    is_observed_intensity_unknown = Column(Boolean)
+
+    def __str__(self) -> str:
+        return ", ".join(
+            [
+                f"<IsotopeDecayMode(id={self.id}",
+                f"isotope_id={self.isotope_id}",
+                f"mode='{self.mode}'",
+                f"intensity={self.intensity})>",
+            ]
+        )
+
+    def __repr__(self) -> str:
+        return str(self)
 
 
 class ScreeningConstant(Base):
@@ -1037,14 +1110,44 @@ class ScreeningConstant(Base):
     s = Column(String)
     screening = Column(Float)
 
-    def __str__(self):
-
+    def __str__(self) -> str:
         return "{0:4d} {1:3d} {2:s} {3:10.4f}".format(
             self.atomic_number, self.n, self.s, self.screening
         )
 
-    def __repr__(self):
-
+    def __repr__(self) -> str:
         return "<ScreeningConstant(Z={0:4d}, n={1:3d}, s={2:s}, screening={3:10.4f})>".format(
             self.atomic_number, self.n, self.s, self.screening
         )
+
+
+class PhaseTransition(Base):
+    """Phase Transition Conditions
+
+    Args:
+        atomic_number (int): Atomic number
+        boiling_point (float): Boiling point in K
+        melting_point (float): Melting points in K
+        critical_temperature (float): Critical temperature in K
+        critical_pressure (float): Critical pressure in MPa
+        triple_point_temperature (float): Temperature in K of the triple point
+        triple_point_pressure (float): Pressure in kPa of the triple point
+    """
+
+    __tablename__ = "phasetransitions"
+
+    id = Column(Integer, primary_key=True)
+    atomic_number = Column(Integer, ForeignKey("elements.atomic_number"))
+    boiling_point = Column(Float)
+    melting_point = Column(Float)
+    critical_temperature = Column(Float)
+    critical_pressure = Column(Float)
+    triple_point_temperature = Column(Float)
+    triple_point_pressure = Column(Float)
+    allotrope = Column(String)
+
+    def __str__(self) -> str:
+        return f"{self.atomic_number} Tm={self.melting_point} Tb={self.boiling_point}"
+
+    def __repr__(self) -> str:
+        return str(self)
\ No newline at end of file
